<!-- !split -->
<!-- jupyter-book 02_testdoc.md -->


# Section 1

<div id="sec1"></div>

Here is a nested list:

  * item1
  * item2
  * item3 which continues
    on the next line to test that feature
  * and a sublist
    * with indented subitem1
    * and a subitem2

  * and perhaps an ordered sublist
   a. first item
   b. second item,
      continuing on a new line


*Here is a list with paragraph heading.*

  * item1
  * item2

#### Here is a list with subsubsection heading

  * item1
  * item2

> Here are two lines that make up
> a block quote for testing *emphasized words* and **boldface words**,
> also with hypens:
> *pre*-fix, post-*fix*, **pre**-fix, post-**fix**.



Here are two references. Equation\ ([my:eq1](my:eq1.html#my:eq1)) is fine. Eq.\ ([my:eq1](my:eq1.html#my:eq1)) too.
Even Equation ([my:eq1](my:eq1.html#my:eq1)) without the tilde.

